Hi Ive just moved from 2.4 so am playing with the progressive sampler. I made a simple model to test the new MSR workflow that vladdo recently explained - in this adaptive works as normal but progressive gets 90% of the image done then drops to 10% cpu utilization and the final image takes almost 3 times longer to do.
I’m using a 6 core hyper threaded i7 / Windows 10 / Max 2016 SP1 / Vray 3.20.03 ..
Am happy to upload the file but its still 13mb even though very simple .. any idea why this is? Thanks -
It would be good to get us a scene to test for this. If you email our support guys at support@chaosgroup.com they can get you FTP info to upload the scene.
We got to the scene you sent us, it was a bit down in the queue.
We got a similar behavior here once the Progressive Sampler reaches pass 750 but the CPU utilization drops gradually from 100%(pass 750) to ~20%(pass 10000).
I’m not sure if this is a bug since there isn’t much change in the image quality after pass 750 - I will forward the case to our developers for further investigation.
Im actually finding this happens a lot with the Progressive sampler (drop off in core utilization) for a variety of scenes making it overall slower for the final image (Vlado was this why you mentioned you use adaptive over progressive for final renders in the thread about the new adaptive sampler you are working on)?
Partly; the other part is memory usage. The CPU usage will be improved, but memory usage for the progressive buffer is much higher that the memory needed for buckets.
From what I can see, a large part of the slowdown comes from the render elements. With the latest nightly builds, with the progressive sampler, the scene renders in 5m 31s without render elements, and for 12m 32s with render elements. For the adaptive sampler, these are respectively 3m 14s and 4m 26s. I guess it’s a thing to look into in more detail and figure out if there’s a way to make it faster. The progressive sampler here has a distinct disadvantage as it must update the final image and the render elements multiple times, whereas the adaptive sampler does it just once after a bucket is complete. Considering that some users have 60+ render elements, this may be quite a bit of work for the CPU.
This is also a fairly simple scene where not much work is spend on actual raytracing compared to everything else; for some of my tests, like in the attached example, the progressive sampler was actually faster than the adaptive one (5m 40s for the progressive vs 6m 44s for the adaptive).